summaryrefslogtreecommitdiffstats
path: root/ipalib/errors.py
diff options
context:
space:
mode:
Diffstat (limited to 'ipalib/errors.py')
-rw-r--r--ipalib/errors.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/ipalib/errors.py b/ipalib/errors.py
index 79ce42dac..9cc4f55cb 100644
--- a/ipalib/errors.py
+++ b/ipalib/errors.py
@@ -913,12 +913,12 @@ class AlreadyActive(ExecutionError):
>>> raise AlreadyActive()
Traceback (most recent call last):
...
AlreadyActive: This entry is already unlocked
"""
errno = 4009
- format = _('This entry is already unlocked')
+ format = _('This entry is already enabled')
class AlreadyInactive(ExecutionError):
"""
@@ -929,12 +929,12 @@ class AlreadyInactive(ExecutionError):
>>> raise AlreadyInactive()
Traceback (most recent call last):
...
AlreadyInactive: This entry is already locked
"""
errno = 4010
- format = _('This entry is already locked')
+ format = _('This entry is already disabled')
class HasNSAccountLock(ExecutionError):
"""
@@ -945,12 +945,12 @@ class HasNSAccountLock(ExecutionError):
>>> raise HasNSAccountLock()
Traceback (most recent call last):
...
HasNSAccountLock: This entry has nsAccountLock set, it cannot be locked or unlocked
"""
errno = 4011
- format = _('This entry has nsAccountLock set, it cannot be locked or unlocked')
+ format = _('This entry cannot be enabled or disabled')
class NotGroupMember(ExecutionError):
"""
@@ -913,12 +913,12 @@ class AlreadyActive(ExecutionError):
Traceback (most recent call last):
...
- AlreadyActive: This entry is already unlocked
+ AlreadyActive: This entry is already enabled
"""
errno = 4009
@@ -929,12 +929,12 @@ class AlreadyInactive(ExecutionError):
Traceback (most recent call last):
...
- AlreadyInactive: This entry is already locked
+ AlreadyInactive: This entry is already disabled
"""
errno = 4010
@@ -945,12 +945,12 @@ class HasNSAccountLock(ExecutionError):
Traceback (most recent call last):
...
- HasNSAccountLock: This entry has nsAccountLock set, it cannot be locked or unlocked
+ HasNSAccountLock: This entry cannot be enableed or disabled
"""
errno = 4011